@@ -1,4 +1,8 @@
 package RapidApp::Error::UserError;
+
+use strict;
+use warnings;
+
 die "Use RapidApp::Responder::UserError instead of RapidApp::Error::UserError";
 
 1;
\ No newline at end of file
