@@ -441,8 +441,9 @@ Ext.ux.RapidApp.ClickActionField = Ext.extend(Ext.ux.RapidApp.UtilField,{
 			this.callActionFn.defer(10,this);
 		}
 	},
-	
+
 	isInForm: function() {
+
 		if(this.ownerCt) {
 			
 			// Special, if in MultiFilter (TODO: clean this up and find a more generaalized
@@ -481,7 +482,10 @@ Ext.ux.RapidApp.ClickActionField = Ext.extend(Ext.ux.RapidApp.UtilField,{
 	},
 	
 	onClickMe: function(e) {
-		this.callActionFn.defer(10,this,arguments);
+    var target = e.getTarget(null,null,true);
+    if(!target.is('a')) {
+      this.callActionFn.defer(10,this,arguments);
+    }
 	},
 	
 	// Make us look like a combo with an 'expand' function:
@@ -728,25 +732,129 @@ Ext.reg('menu-field',Ext.ux.RapidApp.ClickMenuField);
 
 
 Ext.ux.RapidApp.CasUploadField = Ext.extend(Ext.ux.RapidApp.ClickActionField,{
-	
-	// TODO
-	
-	
-	initComponent: function() {
-		Ext.ux.RapidApp.CasUploadField.superclass.initComponent.call(this);
-		
-	}
-	
+
+  // init/default value:
+  //value: '<div style="color:darkgray;">(select file)</div>',
+  value: null,
+
+  uploadUrl: '/simplecas/upload_file',
+  uploadHeading: 'Upload File',
+  selectHeading: 'Select File',
+
+  actionOnShow: true,
+
+  renderValFn: 'Ext.ux.RapidApp.renderCasLink',
+
+  initComponent: function() {
+    // Allow renderValFn to be specified as a string or real func:
+    if(typeof this.renderValFn == 'string') {
+      this.renderValFn = eval(this.renderValFn);
+    }
+
+    Ext.ux.RapidApp.CasUploadField.superclass.initComponent.call(this);
+  },
+
+  getUploadUrl: function() {
+    return this.uploadUrl;
+  },
+
+  formUploadCallback: function(form,res) {
+    var nfo = Ext.decode(res.response.responseText);
+    this.setValue([nfo.checksum,nfo.filename].join('/'));
+    this.onActionComplete();
+  },
+
+  onActionComplete: function() {
+    this.fireEvent.defer(50,this,['select']);
+  },
+
+  getWinFormCfg: function() {
+
+    var fields = [{
+      xtype: 'fileuploadfield',
+      emptyText: this.selectHeading,
+      fieldLabel: this.selectHeading,
+      name: 'Filedata',
+      buttonText: 'Browse',
+      width: 300
+    }];
+
+    var fieldset = {
+      style: 'border: none',
+      hideBorders: true,
+      xtype: 'fieldset',
+      labelWidth: 80,
+      border: false,
+      items:fields
+    };
+
+    var cfg = {
+      title: this.uploadHeading,
+      width: 440,
+      height:140,
+      url: this.getUploadUrl(),
+      useSubmit: true,
+      fileUpload: true,
+      fieldset: fieldset,
+      success: this.formUploadCallback,
+      cancelHandler: this.onActionComplete.createDelegate(this)
+    }
+
+    if(this.allowBlank) {
+      var thisF = this;
+      cfg.extra_buttons = [{
+        text: 'Set None (empty)',
+        iconCls: 'ra-icon-selection',
+        handler: function(btn) {
+          // Set the field to null:
+          thisF.setRawValue.call(thisF,null);
+
+          // Find and call the cancel button which is adjacent to us:
+          var cancelBtn = btn.ownerCt.getComponent('cancel');
+          cancelBtn.handler.call(cancelBtn,cancelBtn);
+        }
+      }]
+    }
+
+    return cfg;
+  },
+
+  actionFn: function() {
+    Ext.ux.RapidApp.WinFormPost.call( this, this.getWinFormCfg() );
+  },
+
+  setRawValue: function(v){
+    if(this.renderValFn){
+      this.dataValue = v;
+      Ext.ux.RapidApp.ClickMenuField.superclass.setRawValue.call(this,this.renderValFn(v));
+    }
+    else {
+      Ext.ux.RapidApp.ClickMenuField.superclass.setRawValue.call(this,v);
+    }
+    return this;
+  },
+
+  getValue: function() {
+    return this.dataValue 
+      ? this.dataValue 
+      : Ext.ux.RapidApp.ClickMenuField.superclass.getValue.call(this);
+  },
+
+  getRawValue: function() {
+    return this.dataValue 
+      ? this.dataValue 
+      : Ext.ux.RapidApp.ClickMenuField.superclass.getRawValue.call(this);
+  }
+
 });
 Ext.reg('cas-upload-field',Ext.ux.RapidApp.CasUploadField);
 
 
 Ext.ux.RapidApp.CasImageField = Ext.extend(Ext.ux.RapidApp.CasUploadField,{
 	
-	// init/default value:
-	value: '<div style="color:darkgray;">(select image)</div>',
-	
 	uploadUrl: '/simplecas/upload_image',
+  uploadHeading: 'Insert Image',
+  selectHeading: 'Select Image',
 	
 	maxImageWidth: null,
 	maxImageHeight: null,
@@ -755,6 +863,7 @@ Ext.ux.RapidApp.CasImageField = Ext.extend(Ext.ux.RapidApp.CasUploadField,{
 	
 	minHeight: 2,
 	minWidth: 2,
+  renderValFn: 'Ext.ux.showNull',
 	
 	getUploadUrl: function() {
 		url = this.uploadUrl;
@@ -810,42 +919,7 @@ Ext.ux.RapidApp.CasImageField = Ext.extend(Ext.ux.RapidApp.CasUploadField,{
 		this.onActionComplete();
 	},
 	
-	onActionComplete: function() {
-		this.fireEvent.defer(50,this,['select']);
-	},
-	
-	actionFn: function(){
-		
-		var upload_field = {
-			xtype: 'fileuploadfield',
-			emptyText: 'Select image',
-			fieldLabel:'Select Image',
-			name: 'Filedata',
-			buttonText: 'Browse',
-			width: 300
-		};
-		
-		var fieldset = {
-			style: 'border: none',
-			hideBorders: true,
-			xtype: 'fieldset',
-			labelWidth: 80,
-			border: false,
-			items:[ upload_field ]
-		};
-		
-		Ext.ux.RapidApp.WinFormPost.call(this,{
-			title: 'Insert Image',
-			width: 440,
-			height:140,
-			url: this.getUploadUrl(),
-			useSubmit: true,
-			fileUpload: true,
-			fieldset: fieldset,
-			success: this.formUploadCallback,
-			cancelHandler: this.onActionComplete.createDelegate(this)
-		});
-	}
+
 	
 });
 Ext.reg('cas-image-field',Ext.ux.RapidApp.CasImageField);
